==> pytigre-0.1.0.tar.gz: pytigre-0.1.0/tigre/demos/Test_data/data_loader.py <==
from __future__ import division
import os
import numpy as np
import scipy.io
import scipy.ndimage.interpolation


def load_head_phantom(number_of_voxels=None):
    if number_of_voxels is None:
        number_of_voxels = np.array((128, 128, 128))
    dirname = os.path.dirname(__file__)
    dirname = os.path.join(dirname,'MRheadbrain')
    dirname = os.path.join(dirname,'head.mat')
    test_data = scipy.io.loadmat(dirname)

    # Loads data in F_CONTIGUOUS MODE (column major), convert to Row major
    image = test_data['img'].copy(order='C')

    image_dimensions = image.shape

    zoom_x = number_of_voxels[0] / image_dimensions[0]
    zoom_y = number_of_voxels[1] / image_dimensions[1]
    zoom_z = number_of_voxels[2] / image_dimensions[2]

    # TODO: add test for this is resizing and not simply zooming
    resized_image = scipy.ndimage.interpolation.zoom(image, (zoom_x, zoom_y, zoom_z), order=3, prefilter=False)

    return resized_image


def load_cube(number_of_voxels=None):
    if number_of_voxels is None:
        number_of_voxels = np.array((128, 128, 128))

    test_data = scipy.io.loadmat('Test_data/cube.mat')

    # Loads data in F_CONTIGUOUS MODE (column major), convert to Row major
    image = test_data['cube'].copy(order='C')

    image_dimensions = image.shape

    zoom_x = number_of_voxels[0] / image_dimensions[0]
    zoom_y = number_of_voxels[1] / image_dimensions[1]
    zoom_z = number_of_voxels[2] / image_dimensions[2]

    # TODO: add test for this is resizing and not simply zooming
    resized_image = scipy.ndimage.interpolation.zoom(image, (zoom_x, zoom_y, zoom_z), order=3, prefilter=False)

    return resized_image

==> pytigre-0.1.2.tar.gz: pytigre-0.1.2/tigre/demos/Test_data/data_loader.py <==
from __future__ import division
import os
import numpy as np
import scipy.io
import scipy.ndimage.interpolation


def load_head_phantom(number_of_voxels=None):
    if number_of_voxels is None:
        number_of_voxels = np.array((128, 128, 128))

    dirname = os.path.dirname(__file__)
    dirname = os.path.join(dirname,'MRheadbrain')
    dirname = os.path.join(dirname,'head.mat')

    test_data = scipy.io.loadmat(dirname)

    # Loads data in F_CONTIGUOUS MODE (column major), convert to Row major
    image = test_data['img'].transpose().copy(order='C')
    image_dimensions = image.shape

    zoom_x = number_of_voxels[0] / image_dimensions[0]
    zoom_y = number_of_voxels[1] / image_dimensions[1]
    zoom_z = number_of_voxels[2] / image_dimensions[2]

    # TODO: add test for this is resizing and not simply zooming
    resized_image = scipy.ndimage.interpolation.zoom(image, (zoom_x, zoom_y, zoom_z), order=3, prefilter=False)

    return resized_image


def load_cube(number_of_voxels=None):
    if number_of_voxels is None:
        number_of_voxels = np.array((128, 128, 128))

    test_data = scipy.io.loadmat(os.path.join(os.path.dirname(__file__),'cube.mat'))

    # Loads data in F_CONTIGUOUS MODE (column major), convert to Row major
    image = test_data['cube'].copy(order='C')

    image_dimensions = image.shape

    zoom_x = number_of_voxels[0] / image_dimensions[0]
    zoom_y = number_of_voxels[1] / image_dimensions[1]
    zoom_z = number_of_voxels[2] / image_dimensions[2]

    # TODO: add test for this is resizing and not simply zooming
    resized_image = scipy.ndimage.interpolation.zoom(image, (zoom_x, zoom_y, zoom_z), order=3, prefilter=False)

    return resized_image
